==> gnuradio-docs-3.10.12.0-7-x86_64.pkg.tar.zst: usr/share/doc/gnuradio/html/group__misc__blk.js <==
var group__misc__blk =
[
    [ "gr::blocks::check_lfsr_32k_s", "classgr_1_1blocks_1_1check__lfsr__32k__s.html", [
      [ "sptr", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a7f103c39f2fcfa7b67a3368e824e927c", null ],
      [ "make", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a85e501ee837450f95fbc1a0bfc8e9d01", null ],
      [ "nright", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a0bbd22562ee0eccbcfd8d9668e3e651e", null ],
      [ "ntotal", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a53d63a6326b7f45ea691f4f0b0f9bb37", null ],
      [ "runlength", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a16b1b7b0966dae60b21332177d9fcaa5", null ]
    ] ],
    [ "gr::blocks::copy", "classgr_1_1blocks_1_1copy.html", [
      [ "sptr", "classgr_1_1blocks_1_1copy.html#a29af60b9fa368e1cea8a31579798e980", null ],
      [ "enabled", "classgr_1_1blocks_1_1copy.html#ae65e456e339c576030f6f1a8187227ec", null ],
      [ "make", "classgr_1_1blocks_1_1copy.html#a6019a24dcee260db470aadcdbad466b9", null ],
      [ "set_enabled", "classgr_1_1blocks_1_1copy.html#a3be406ed10fea768eba624ea02af6cbe", null ]
    ] ],
    [ "gr::blocks::delay", "classgr_1_1blocks_1_1delay.html", [
      [ "sptr", "classgr_1_1blocks_1_1delay.html#a67eb1e0c924561e8ba51553f70e85325", null ],
      [ "dly", "classgr_1_1blocks_1_1delay.html#ac5f0f9cf44b84f2f6c77b1dbc8fc2ccf", null ],
      [ "make", "classgr_1_1blocks_1_1delay.html#afb3f9733fb6b7f4f9c69dd397f1dcad5", null ],
      [ "set_dly", "classgr_1_1blocks_1_1delay.html#ad4c08709073a3f5e2f1729bc5c168c58", null ]
    ] ],
    [ "gr::blocks::head", "classgr_1_1blocks_1_1head.html", [
      [ "sptr", "classgr_1_1blocks_1_1head.html#ac696bbc8f295959df34801bc6c99996e", null ],
      [ "make", "classgr_1_1blocks_1_1head.html#a406bf5ec53c62ca4cb76de86e27dc942", null ],
      [ "reset", "classgr_1_1blocks_1_1head.html#abdd0b2699c7026e83500adc39731de9e", null ],
      [ "set_length", "classgr_1_1blocks_1_1head.html#a03894a817d3b49a2e5bb70d64464bfa6", null ]
    ] ],
    [ "gr::blocks::lfsr_32k_source_s", "classgr_1_1blocks_1_1lfsr__32k__source__s.html", [
      [ "sptr", "classgr_1_1blocks_1_1lfsr__32k__source__s.html#ac096b3a20136865632c1e5c3c5e5309a", null ],
      [ "make", "classgr_1_1blocks_1_1lfsr__32k__source__s.html#af0314f94277a11b570de5e97e89b9c0a", null ]
    ] ],
    [ "gr::blocks::nop", "classgr_1_1blocks_1_1nop.html", [
      [ "sptr", "classgr_1_1blocks_1_1nop.html#acc558b1ebfe4dcaad0a9da4a65b182b7", null ],
      [ "ctrlport_test", "classgr_1_1blocks_1_1nop.html#a0effd648208ec8577be6182b2b4e63e7", null ],
      [ "make", "classgr_1_1blocks_1_1nop.html#a76625c7e811fbc35c8db51a229b24c34", null ],
      [ "nmsgs_received", "classgr_1_1blocks_1_1nop.html#a06e324a9a98dfa5548405559c87031f2", null ],
      [ "set_ctrlport_test", "classgr_1_1blocks_1_1nop.html#aa0dacef11b871d928ad155294c486232", null ]
    ] ],
    [ "gr::blocks::null_sink", "classgr_1_1blocks_1_1null__sink.html", [
      [ "sptr", "classgr_1_1blocks_1_1null__sink.html#a5064b99c17bca9676568ef80f01d2a98", null ],
      [ "make", "classgr_1_1blocks_1_1null__sink.html#a874ef75ab160a8ff055aa83676cc0ce6", null ]
    ] ],
    [ "gr::blocks::null_source", "classgr_1_1blocks_1_1null__source.html", [
      [ "sptr", "classgr_1_1blocks_1_1null__source.html#aede1a2015491b4ae3c93d735feb08e58", null ],
      [ "make", "classgr_1_1blocks_1_1null__source.html#ac0e753e512f4ecb683bc7f20eba6cb4a", null ]
    ] ],
    [ "gr::blocks::phase_shift", "classgr_1_1blocks_1_1phase__shift.html", [
      [ "sptr", "classgr_1_1blocks_1_1phase__shift.html#aadde08e09839f568b2624f035ba3a415", null ],
      [ "get_shift", "classgr_1_1blocks_1_1phase__shift.html#afb571bfd55d7ee18968e437c4f399338", null ],
      [ "make", "classgr_1_1blocks_1_1phase__shift.html#a3f1579aa1fba63848296b505ccee0e68", null ],
      [ "set_shift", "classgr_1_1blocks_1_1phase__shift.html#aee599c8c55f4c75a4364fdea40eb92a5", null ]
    ] ],
    [ "gr::blocks::selector", "classgr_1_1blocks_1_1selector.html", [
      [ "sptr", "classgr_1_1blocks_1_1selector.html#a3165da8e93b37637c9d55886b1fef553", null ],
      [ "enabled", "classgr_1_1blocks_1_1selector.html#abf28edb43a04313fa18e3d14227523de", null ],
      [ "input_index", "classgr_1_1blocks_1_1selector.html#a176a7066473edb645ceabeabe6fdd9d8", null ],
      [ "make", "classgr_1_1blocks_1_1selector.html#a2ee6c443ee51c5af824f294c87f1bfc1", null ],
      [ "output_index", "classgr_1_1blocks_1_1selector.html#aca3644d36a12222a2e05b2f6de2d8a2a", null ],
      [ "set_enabled", "classgr_1_1blocks_1_1selector.html#affbe7c9adf2c7c47d8e63460a96773b8", null ],
      [ "set_input_index", "classgr_1_1blocks_1_1selector.html#ac906599429aa829ff257e87701d40ac1", null ],
      [ "set_output_index", "classgr_1_1blocks_1_1selector.html#a1cd616c082ec23e3feb38ffa9fbfc10e", null ]
    ] ],
    [ "gr::blocks::skiphead", "classgr_1_1blocks_1_1skiphead.html", [
      [ "sptr", "classgr_1_1blocks_1_1skiphead.html#aea6d5cb602816fd5a25c648ff4f20ab2", null ],
      [ "make", "classgr_1_1blocks_1_1skiphead.html#a2e12662420794a9e63bc25bb476f91eb", null ]
    ] ],
    [ "gr::blocks::throttle", "classgr_1_1blocks_1_1throttle.html", [
      [ "sptr", "classgr_1_1blocks_1_1throttle.html#ad8fe282adcc4f2b68a8beae58add4281", null ],
      [ "make", "classgr_1_1blocks_1_1throttle.html#aeb3cef578379c84d21c297b5145b7839", null ],
      [ "maximum_items_per_chunk", "classgr_1_1blocks_1_1throttle.html#a98e5816ab4fae152e629343603a7104a", null ],
      [ "sample_rate", "classgr_1_1blocks_1_1throttle.html#a614abc14100c79deb0b75dfdbf10889d", null ],
      [ "set_maximum_items_per_chunk", "classgr_1_1blocks_1_1throttle.html#a1284b4382acff352b6eaa64b9afa8942", null ],
      [ "set_sample_rate", "classgr_1_1blocks_1_1throttle.html#a68bac1f10438f07d5b4dc57d2e52119a", null ]
    ] ],
    [ "gr::blocks::vector_source< T >", "classgr_1_1blocks_1_1vector__source.html", [
      [ "sptr", "classgr_1_1blocks_1_1vector__source.html#a8fe9d939565115df06e919ba819f353a", null ],
      [ "make", "classgr_1_1blocks_1_1vector__source.html#a58034344d985f982478c67b03358b3a3", null ],
      [ "rewind", "classgr_1_1blocks_1_1vector__source.html#ac6b551a68d2b7d8b898a49fedf31bc24", null ],
      [ "set_data", "classgr_1_1blocks_1_1vector__source.html#a9c671c5bd9d56cdeb5ca2fe3e4b64892", null ],
      [ "set_repeat", "classgr_1_1blocks_1_1vector__source.html#a94be87b889a05ca85ef034ce727c39e0", null ]
    ] ]
];

==> gnuradio-docs-3.10.12.0-10-x86_64.pkg.tar.zst: usr/share/doc/gnuradio/html/group__misc__blk.js <==
var group__misc__blk =
[
    [ "gr::blocks::check_lfsr_32k_s", "classgr_1_1blocks_1_1check__lfsr__32k__s.html", [
      [ "sptr", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a7f103c39f2fcfa7b67a3368e824e927c", null ],
      [ "make", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a85e501ee837450f95fbc1a0bfc8e9d01", null ],
      [ "nright", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a0bbd22562ee0eccbcfd8d9668e3e651e", null ],
      [ "ntotal", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a53d63a6326b7f45ea691f4f0b0f9bb37", null ],
      [ "runlength", "classgr_1_1blocks_1_1check__lfsr__32k__s.html#a16b1b7b0966dae60b21332177d9fcaa5", null ]
    ] ],
    [ "gr::blocks::copy", "classgr_1_1blocks_1_1copy.html", [
      [ "sptr", "classgr_1_1blocks_1_1copy.html#a29af60b9fa368e1cea8a31579798e980", null ],
      [ "enabled", "classgr_1_1blocks_1_1copy.html#ae65e456e339c576030f6f1a8187227ec", null ],
      [ "make", "classgr_1_1blocks_1_1copy.html#a6019a24dcee260db470aadcdbad466b9", null ],
      [ "set_enabled", "classgr_1_1blocks_1_1copy.html#a3be406ed10fea768eba624ea02af6cbe", null ]
    ] ],
    [ "gr::blocks::delay", "classgr_1_1blocks_1_1delay.html", [
      [ "sptr", "classgr_1_1blocks_1_1delay.html#a67eb1e0c924561e8ba51553f70e85325", null ],
      [ "dly", "classgr_1_1blocks_1_1delay.html#ac5f0f9cf44b84f2f6c77b1dbc8fc2ccf", null ],
      [ "make", "classgr_1_1blocks_1_1delay.html#afb3f9733fb6b7f4f9c69dd397f1dcad5", null ],
      [ "set_dly", "classgr_1_1blocks_1_1delay.html#ad4c08709073a3f5e2f1729bc5c168c58", null ]
    ] ],
    [ "gr::blocks::head", "classgr_1_1blocks_1_1head.html", [
      [ "sptr", "classgr_1_1blocks_1_1head.html#ac696bbc8f295959df34801bc6c99996e", null ],
      [ "make", "classgr_1_1blocks_1_1head.html#a406bf5ec53c62ca4cb76de86e27dc942", null ],
      [ "reset", "classgr_1_1blocks_1_1head.html#abdd0b2699c7026e83500adc39731de9e", null ],
      [ "set_length", "classgr_1_1blocks_1_1head.html#a03894a817d3b49a2e5bb70d64464bfa6", null ]
    ] ],
    [ "gr::blocks::lfsr_32k_source_s", "classgr_1_1blocks_1_1lfsr__32k__source__s.html", [
      [ "sptr", "classgr_1_1blocks_1_1lfsr__32k__source__s.html#ac096b3a20136865632c1e5c3c5e5309a", null ],
      [ "make", "classgr_1_1blocks_1_1lfsr__32k__source__s.html#af0314f94277a11b570de5e97e89b9c0a", null ]
    ] ],
    [ "gr::blocks::nop", "classgr_1_1blocks_1_1nop.html", [
      [ "sptr", "classgr_1_1blocks_1_1nop.html#acc558b1ebfe4dcaad0a9da4a65b182b7", null ],
      [ "ctrlport_test", "classgr_1_1blocks_1_1nop.html#a0effd648208ec8577be6182b2b4e63e7", null ],
      [ "make", "classgr_1_1blocks_1_1nop.html#a76625c7e811fbc35c8db51a229b24c34", null ],
      [ "nmsgs_received", "classgr_1_1blocks_1_1nop.html#a06e324a9a98dfa5548405559c87031f2", null ],
      [ "set_ctrlport_test", "classgr_1_1blocks_1_1nop.html#aa0dacef11b871d928ad155294c486232", null ]
    ] ],
    [ "gr::blocks::null_sink", "classgr_1_1blocks_1_1null__sink.html", [
      [ "sptr", "classgr_1_1blocks_1_1null__sink.html#a5064b99c17bca9676568ef80f01d2a98", null ],
      [ "make", "classgr_1_1blocks_1_1null__sink.html#a874ef75ab160a8ff055aa83676cc0ce6", null ]
    ] ],
    [ "gr::blocks::null_source", "classgr_1_1blocks_1_1null__source.html", [
      [ "sptr", "classgr_1_1blocks_1_1null__source.html#aede1a2015491b4ae3c93d735feb08e58", null ],
      [ "make", "classgr_1_1blocks_1_1null__source.html#ac0e753e512f4ecb683bc7f20eba6cb4a", null ]
    ] ],
    [ "gr::blocks::phase_shift", "classgr_1_1blocks_1_1phase__shift.html", [
      [ "sptr", "classgr_1_1blocks_1_1phase__shift.html#aadde08e09839f568b2624f035ba3a415", null ],
      [ "get_shift", "classgr_1_1blocks_1_1phase__shift.html#afb571bfd55d7ee18968e437c4f399338", null ],
      [ "make", "classgr_1_1blocks_1_1phase__shift.html#a3f1579aa1fba63848296b505ccee0e68", null ],
      [ "set_shift", "classgr_1_1blocks_1_1phase__shift.html#aee599c8c55f4c75a4364fdea40eb92a5", null ]
    ] ],
    [ "gr::blocks::selector", "classgr_1_1blocks_1_1selector.html", [
      [ "sptr", "classgr_1_1blocks_1_1selector.html#a3165da8e93b37637c9d55886b1fef553", null ],
      [ "enabled", "classgr_1_1blocks_1_1selector.html#abf28edb43a04313fa18e3d14227523de", null ],
      [ "input_index", "classgr_1_1blocks_1_1selector.html#a176a7066473edb645ceabeabe6fdd9d8", null ],
      [ "make", "classgr_1_1blocks_1_1selector.html#a2ee6c443ee51c5af824f294c87f1bfc1", null ],
      [ "output_index", "classgr_1_1blocks_1_1selector.html#aca3644d36a12222a2e05b2f6de2d8a2a", null ],
      [ "set_enabled", "classgr_1_1blocks_1_1selector.html#affbe7c9adf2c7c47d8e63460a96773b8", null ],
      [ "set_input_index", "classgr_1_1blocks_1_1selector.html#ac906599429aa829ff257e87701d40ac1", null ],
      [ "set_output_index", "classgr_1_1blocks_1_1selector.html#a1cd616c082ec23e3feb38ffa9fbfc10e", null ]
    ] ],
    [ "gr::blocks::skiphead", "classgr_1_1blocks_1_1skiphead.html", [
      [ "sptr", "classgr_1_1blocks_1_1skiphead.html#aea6d5cb602816fd5a25c648ff4f20ab2", null ],
      [ "make", "classgr_1_1blocks_1_1skiphead.html#a2e12662420794a9e63bc25bb476f91eb", null ]
    ] ],
    [ "gr::blocks::throttle", "classgr_1_1blocks_1_1throttle.html", [
      [ "sptr", "classgr_1_1blocks_1_1throttle.html#ad8fe282adcc4f2b68a8beae58add4281", null ],
      [ "make", "classgr_1_1blocks_1_1throttle.html#aeb3cef578379c84d21c297b5145b7839", null ],
      [ "maximum_items_per_chunk", "classgr_1_1blocks_1_1throttle.html#a98e5816ab4fae152e629343603a7104a", null ],
      [ "sample_rate", "classgr_1_1blocks_1_1throttle.html#a614abc14100c79deb0b75dfdbf10889d", null ],
      [ "set_maximum_items_per_chunk", "classgr_1_1blocks_1_1throttle.html#a1284b4382acff352b6eaa64b9afa8942", null ],
      [ "set_sample_rate", "classgr_1_1blocks_1_1throttle.html#a68bac1f10438f07d5b4dc57d2e52119a", null ]
    ] ],
    [ "gr::blocks::vector_source&lt; T &gt;", "classgr_1_1blocks_1_1vector__source.html", [
      [ "sptr", "classgr_1_1blocks_1_1vector__source.html#a8fe9d939565115df06e919ba819f353a", null ],
      [ "make", "classgr_1_1blocks_1_1vector__source.html#a58034344d985f982478c67b03358b3a3", null ],
      [ "rewind", "classgr_1_1blocks_1_1vector__source.html#ac6b551a68d2b7d8b898a49fedf31bc24", null ],
      [ "set_data", "classgr_1_1blocks_1_1vector__source.html#a9c671c5bd9d56cdeb5ca2fe3e4b64892", null ],
      [ "set_repeat", "classgr_1_1blocks_1_1vector__source.html#a94be87b889a05ca85ef034ce727c39e0", null ]
    ] ]
];
